# pyGenomeViz Viewer

$PGV_SVG_FIG

Label Text:

Label Size:

- Zoom Figure
  By clicking plus-minus button or moving mouse wheel, figure can be zoomed.
- Reset Zoom Figure
  By clicking reset button, figure can be reset zoom status.
- Pan Figure
  By dragging figure, figure can be panned freely.
- Select Color
  By clicking color picker button, user can select object change color.
- Change Object Color
  By double-clicking on a Feature | Link | Text object, object color can be changed.
- Change Text Property
  By right-clicking on the text label, edit dialog appears.
- Save Figure
  By clicking save button, user can save figure in PNG or SVG format.
- Save Edited HTML State
  By entering [Ctrl + S], user can save edited HTML as a new file.

pyGenomeViz v$VERSION
$DATETIME_NOW
GitHub | Document